<?php


add_filter( 'rwmb_meta_boxes', 'airpro_register_meta_boxes' );

function airpro_get_metaboxes_for_layout_options() {
    $prefix = AIRPRO_PREFIX;

    return array(
		'title' => __( 'Layout Options', 'airpro' ),
        'post_types' => array( 'post', 'page' ),
		'fields' => array(
            array(
                'id'               => $prefix . 'page_sidebar_layout',
                'type'             => 'select',
                'name'             => esc_html__( 'Page - Sidebars Position', 'airpro' ),
                'options'          => array(
                    'left' => __( 'Left', 'airpro' ),
                    'right' => __( 'Right', 'airpro' ),
					'none'  => __( 'No Sidebar', 'airpro' )
				),
                'std'              => 'default',
                'desc'    => esc_html__( 'Select sidebars position. Choose between left, right or no sidebars layout. If any option except "Default" is selected, it will override the global parameter chosen in Theme Options.', 'airpro' ),
				'placeholder' => esc_html( 'Default' )
            ),
			array(
				// more information about "switch" is available here, but unfortunately some of it doesn't seem to work correctly (e.g. setting default value)
				'id'          => $prefix . 'should_use_page_title',
				'type'        => 'select',
				'name'        => esc_html__( 'Use Page Title?', 'airpro' ),
				'desc'        => esc_html__( 'Show or hide the page title section.', 'airpro' ),
				'options' => array(
					true => esc_html__( 'Yes', 'airpro' ),
					false => esc_html__( 'No', 'airpro' )
				),
				'placeholder' => esc_html( 'Default' )
			),
			array(
				'id'          => $prefix . 'page_title_breadcrumbs',
				'type'        => 'select',
				'name'        => esc_html__( 'Enable Breadcrumbs?', 'airpro' ),
				'desc'        => esc_html__( 'Show or hide the breadcrumbs section.', 'airpro' ),
				'options' => array(
					true => esc_html__( 'Yes', 'airpro' ),
					false => esc_html__( 'No', 'airpro' )
				),
				'placeholder' => esc_html( 'Default' )
			),
            array(
				'id'               => $prefix . 'use_header',
                'type'             => 'select',
				'name'             => esc_html__( 'Use Header?', 'airpro' ),
                'options'          => array(
                    'on' => __( 'Yes', 'airpro' ),
                    'off' => __( 'No', 'airpro')
                ),
                'std'              => 'default',
				'desc'             => esc_html__( 'Show or hide the header. If any option except "Default" is selected, it will override the global parameter chosen in Theme Options.', 'airpro' ),
				'placeholder' => esc_html( 'Default' )
            ),
            array(
				'id'               => $prefix . 'use_footer',
                'type'             => 'select',
				'name'             => esc_html__( 'Use Footer?', 'airpro' ),
                'options'          => array(
                    'on' => __( 'Yes', 'airpro' ),
                    'off' => __( 'No', 'airpro')
                ),
                'std'              => 'default',
				'desc'             => esc_html__( 'Show or hide the footer. If any option except "Default" is selected, it will override the global parameter chosen in Theme Options.', 'airpro' ),
				'placeholder' => esc_html( 'Default' )
			)
        )
    );    
}

function airpro_register_meta_boxes( $meta_boxes ) {
	$meta_boxes = array();
	$prefix     = 'airpro_';

	/**
	 * Pages
	 */

	$menus       = get_registered_nav_menus();
	$menus_array = array();

	foreach ( $menus as $location => $description ) {
		$menus_array[ $location ] = $description;
	}

	$layout_blocks = get_posts(array(
		'post_type' => 'layout_block',
		'numberposts' => -1));
	$layout_blocks_array = array();
	foreach ( $layout_blocks as $layout_block ) {
		$layout_blocks_array[ $layout_block->ID ] = $layout_block->post_title;
	}


	$meta_boxes[] = array(
		'title'  => 'Page Settings',
		'pages'  => array( 'page' ), // can be used on multiple CPTs
		'fields' => array(
			array(
				'id'               => $prefix . 'custom_logo',
				'type'             => 'image_advanced',
				'name'             => esc_html__( 'Custom Logo', 'airpro' ),
				'desc'             => esc_html__( 'Used it to override the logo from theme options. This works well when using Transparent Header Template.', 'airpro' ),
				'max_file_uploads' => 1,
			),
			array(
				'id'          => $prefix . 'top_bar_layout_block',
				'type'        => 'select',
				'name'        => esc_html( 'Top Bar Layout Block', 'airpro' ),
				'desc'        => esc_html( 'Override Theme Options settings.', 'airpro' ),
				'options'     => $layout_blocks_array,
				'placeholder' => esc_html( 'Default' ),
			),
			array(
				'id'          => $prefix . 'footer_layout_block',
				'type'        => 'select',
				'name'        => esc_html( 'Footer Layout Block', 'airpro' ),
				'desc'        => esc_html( 'Override Theme Options settings.', 'airpro' ),
				'options'     => $layout_blocks_array,
				'placeholder' => esc_html( 'Default' ),
			),
			array(
				'id'      => $prefix . 'page_content_padding',
				'name'    => esc_html__( 'Content Padding - Top and Bottom (in px)', 'airpro' ),
				'type'    => 'fieldset_text',
				'options' => array(
					'top'    => esc_html__( 'Top', 'airpro' ),
					'bottom'   => esc_html__( 'Bottom', 'airpro' )
				),			
				// Is field cloneable?
				'clone' => false
			),
			array(
				'id'          => $prefix . 'page_title_background',
				'type'        => 'background',
				'name'        => esc_html( 'Page Title Background', 'airpro' ),
				'desc'        => esc_html( 'Override page title bar background.', 'airpro' ),
				'clone'       => true
			)
		)
	);
    
	$meta_boxes[] = airpro_get_metaboxes_for_layout_options();

	return $meta_boxes;
}
