<?php

/**
 * Utility functions
 */
function airpro_add_filters( $tags, $function ) {
	foreach ( $tags as $tag ) {
		add_filter( $tag, $function );
	}
}

function airpro_is_element_empty( $element ) {
	$element = trim( $element );

	return empty( $element ) ? true : false;
}

function airpro_get_thumbnail( $thumbnail = 'thumbnail', $echo = true ) {
	global $post_id;

	$img_url = '';
	if ( has_post_thumbnail( $post_id ) ) {
		$img_url = get_the_post_thumbnail( $post_id, $thumbnail, array(
			'class' => $thumbnail
		) );
	}
	$out = '';
	if ( '' != $img_url ) {
		$out = '<a href="' . get_permalink( $post_id ) . '" title="' . esc_attr( get_post_field( 'post_title', $post_id ) ) . '">' . $img_url . '</a>';
	}
	if ( $echo ) {
		echo $out;
	} else {
		return $out;
	}
}

function airpro_pagination( $pages = '', $range = 2 ) {
	$showitems = ( $range * 2 ) + 1;

	global $paged;
	if ( empty( $paged ) ) {
		$paged = 1;
	}

	if ( $pages == '' ) {
		global $wp_query;
		$pages = $wp_query->max_num_pages;
		if ( ! $pages ) {
			$pages = 1;
		}
	}

	if ( 1 != $pages ) {
		echo "<div class='pagination'>";
		if ( $paged > 2 && $paged > $range + 1 && $showitems < $pages ) {
			echo "<a href='" . get_pagenum_link( 1 ) . "'>&laquo;</a>";
		}
		if ( $paged > 1 && $showitems < $pages ) {
			echo "<a href='" . get_pagenum_link( $paged - 1 ) . "'>&lsaquo;</a>";
		}

		for ( $i = 1; $i <= $pages; $i ++ ) {
			if ( 1 != $pages && ( ! ( $i >= $paged + $range + 1 || $i <= $paged - $range - 1 ) || $pages <= $showitems ) ) {
				echo ( $paged == $i ) ? "<span class='current'>" . $i . "</span>" : "<a href='" . get_pagenum_link( $i ) . "' class='inactive' >" . $i . "</a>";
			}
		}

		if ( $paged < $pages && $showitems < $pages ) {
			echo "<a href='" . get_pagenum_link( $paged + 1 ) . "'>&rsaquo;</a>";
		}
		if ( $paged < $pages - 1 && $paged + $range - 1 < $pages && $showitems < $pages ) {
			echo "<a href='" . get_pagenum_link( $pages ) . "'>&raquo;</a>";
		}
		echo "</div>\n";
	}
}

function airpro_grid_class_map() {

	return array(
		array( 'one twelfth', 'eleven twelfths' ), // 1/11
		array( 'one sixth', 'five sixths' ),     // 2/10
		array( 'one fourth', 'three fourths' ),   // 3/9
		array( 'one third', 'two thirds' ),      // 4/8
		array( 'five twelfths', 'seven twelfths' ),  // 5/7
		array( 'one half', 'one half' ),        // 6/6
		array( 'seven twelfths', 'five twelfths' ),   // 7/5
		array( 'two thirds', 'one third' ),       // 8/4
		array( 'three fourths', 'one fourth' ),      // 9/3
		array( 'five sixths', 'one sixth' ),       // 10/2
		array( 'eleven twelfths', 'one twelfth' ),     // 11/1
		array( 'one whole', 'one whole' ),       // 12/12
	);
}

function airpro_get_grid_class( $index, $invert = false ) {
	$grid = airpro_grid_class_map();
	return isset( $grid[ $index ]) ? $grid[ $index ][ $invert ? 1 : 0 ] : '';
}

function airpro_get_option( $option_name, $default = false ) {
	$options = isset($GLOBALS[ AIRPRO_THEME_OPTION_NAME ]) ? $GLOBALS[ AIRPRO_THEME_OPTION_NAME ] : false;

	if ( $options && is_string( $option_name ) ) {
		return isset( $options[ $option_name ] ) ? $options[ $option_name ] : $default;
	}

	return $default;
}

function airpro_get_page_template() {

	$post_id = null;
	if ( isset( $_GET['post'] ) ) {
		$post_id = $_GET['post'];
	} elseif ( isset( $_POST['post_ID'] ) ) {
		$post_id = $_POST['post_ID'];
	} else {
		global $post;
		$post_id = $post->ID;
	}

	if ( $post_id ) {
		return get_post_meta( $post_id, '_wp_page_template', true );
	}

}

function airpro_is_page_template( $template_file ) {
	return airpro_get_page_template() == $template_file;
}

function airpro_custom_css() {
	$custom_css = airpro_get_option( 'custom-css' );
	if ( ! airpro_is_element_empty( $custom_css ) ) {
		echo '<style>' . $custom_css . '</style>' . "\n";
	}
}

function airpro_custom_js_code() {
	$customJsCode = airpro_get_option( 'custom-js-code', false );
	if ( $customJsCode ) {
		echo '<script id="wh-custom-js-code">' . "\n" . $customJsCode . "\n</script>\n";
	}
}

function airpro_responsive_menu_scripts() {

	$respmenu_use                      = (int) airpro_get_option( 'respmenu-use', 1 );
	$respmenu_show_start               = (int) airpro_get_option( 'respmenu-show-start', 767 );
	$respmenu_logo                     = airpro_get_option( 'respmenu-logo', array() );
	$respmenu_logo_url                 = isset( $respmenu_logo['url'] ) && $respmenu_logo['url'] ? $respmenu_logo['url'] : '';
	$respmenu_display_switch_logo      = airpro_get_option( 'respmenu-display-switch-img', array() );
	$respmenu_display_switch_logo_url  = isset( $respmenu_display_switch_logo['url'] ) && $respmenu_display_switch_logo['url'] ? $respmenu_display_switch_logo['url'] : '';


	if ( $respmenu_use && $respmenu_show_start ) {
	?>
	<style>
		@media screen and (max-width: <?php echo intval( $respmenu_show_start ); ?>px) {
			#cbp-menu-main { width: 100%; }

			.wh-main-menu { display: none; }
			.wh-header { display: none; }
		}
	</style>
	<script>
		var wheels  = wheels || {};
		wheels.data = wheels.data || {};

		wheels.data.respmenu = {
			id: 'cbp-menu-main',
			options: {
				id: 'cbp-menu-main-respmenu',
				submenuToggle: {
					className: 'cbp-respmenu-more',
					html: '<i class="fa fa-angle-down"></i>'
				},
				logo: {
					src: <?php echo json_encode( $respmenu_logo_url ); ?>,
					link: '<?php echo esc_url( home_url( '/' ) ); ?>'
				},
				toggleSwitch: {
					src: <?php echo json_encode( $respmenu_display_switch_logo_url ); ?>
				},
				prependTo: 'body',
				skipClasses: ['wcmenucart-contents', 'crea-woocommerce-wrapper']
			}
		};
	</script>
	<?php
	}


}

function airpro_filter_array( $filter_name, $default = array() ) {

	$filtered = apply_filters( $filter_name, $default);

	if ( ! is_array( $filtered ) || ! count( $filtered ) ) {
		$filtered = $default;
	}

	return array_unique( $filtered );
}

function airpro_array_val_concat( $array = null, $postfix = '', $default ) {

	if ( is_array( $array ) ) {

		$res = array();

		foreach ( $array as $val) {
			$res[] = $val . $postfix;
		}

		return $res;
	}

	return $default;
}

function airpro_get_rwmb_meta( $key, $post_id, $options = array() ) {
	$prefix = 'airpro_';
	$value = false;

	if ( function_exists( 'rwmb_meta' ) ) {
		$value = rwmb_meta( $prefix . $key, $options, $post_id );
	}
	return $value;
}

function airpro_get_rwmb_meta_value( $key, $post_id, $options = array() ) {
	$prefix = 'airpro_';
	$value = false;

	// https://docs.metabox.io/rwmb-the-value/
	if ( function_exists( 'rwmb_the_value' ) ) {
		$value = rwmb_get_value( $prefix . $key, $options, $post_id );
	}

	return $value;
}

function airpro_get_logo_url() {
	$logo_url = '';

	// Get custom page logo
	global $post;
	if ($post) {

		$logo = airpro_get_rwmb_meta('custom_logo', $post->ID, array('type' => 'image'));
		if ( is_array( $logo ) && count( $logo ) ) {
			$logo = reset( $logo );	// get first element

			$logo_url = isset( $logo['full_url'] ) ? $logo['full_url'] : '';
			return $logo_url;
		}
	}

	// Get default logo
	$logo     = airpro_get_option( 'logo', array() );
	$logo_url = isset( $logo['url'] ) && $logo['url'] ? $logo['url'] : '';


	return $logo_url;
}

function airpro_get_logo_meta() {
	$logo_url = '';

	// Get custom page logo
	global $post;
	if ($post) {
		$logo = airpro_get_rwmb_meta('custom_logo', $post->ID, array('type' => 'image'));
		if ( ! empty( $logo ) ) {
			$logo_meta = array_values( $logo );
			
			return array(
				'alt' => $logo_meta[ 0 ][ 'alt' ],
				'title' => $logo_meta[ 0 ][ 'title' ]
			);
		}
	}

	// Get default logo
	$logo     = airpro_get_option( 'logo', array() );
	$logo_meta = wp_prepare_attachment_for_js( $logo[ 'id' ] );
	
	return array(
		'alt' => $logo_meta[ 'alt' ],
		'title' => $logo_meta[ 'title' ]
	);
}

function airpro_strip_comments( $string ) {

	$regex = array(
		"`^([\t\s]+)`ism"=>'',
		"`^\/\*(.+?)\*\/`ism"=>"",
		"`([\n\A;]+)\/\*(.+?)\*\/`ism"=>"$1",
		"`//(.+?)[\n\r]`ism"=>"",
		"`([\n\A;\s]+)//(.+?)[\n\r]`ism"=>"$1\n",
		"`(^[\r\n]*|[\r\n]+)[\s\t]*[\r\n]+`ism"=>"\n"
	);

	return preg_replace( array_keys( $regex ), $regex, $string );
}

function airpro_get_layout_block( $key ) {

	global $post;
	$layout_block_id = null;

	if  ( $post ) {
		$layout_block_id = airpro_get_rwmb_meta( str_replace( '-', '_', $key ), $post->ID );
	}
	if ( ! $layout_block_id ) {
		$layout_block_id = airpro_get_option( $key, false );
	}

	if ( $layout_block_id ) {
		$layout_block = get_post( $layout_block_id );
		return $layout_block;
	}
}

function airpro_get_layout_option( $key ) {
	global $post;
	$layout_option_value = null;

	$more_specific_layout_setting_identifiers = array(
		'page-sidebar-layout' => array(
			'default' => 'page-sidebar-layout',
			'blog' => 'blog-archive-sidebar-layout',
			'blog-single' => 'blog-single-sidebar-layout',
			'woocommerce-shop-page' => 'woocommerce-shop-page-sidebar-layout',
			'woocommerce-product' => 'woocommerce-product-sidebar-layout'
		),
		'use-header' => array(
			'default' => 'use-header',
			'blog' => 'use-header',
			'blog-single' => 'use-header',
			'woocommerce-shop-page' => 'use-header',
			'woocommerce-product' => 'use-header'
		),
		'use-footer' => array(
			'default' => 'use-footer',
			'blog' => 'use-footer',
			'blog-single' => 'use-footer',
			'woocommerce-shop-page' => 'use-footer',
			'woocommerce-product' => 'use-footer'
		)
	);

	$subcategory = 'default';
	if ( is_home() ) {
		$subcategory = 'blog';
	}
	elseif ( is_singular( 'post' ) ) {
		$subcategory = 'blog-single';
	}
	elseif ( is_singular( array( 'product' ) ) ) {
		$subcategory = 'woocommerce-product';
	}
	elseif ( is_post_type_archive( 'product' ) ) {	// https://wordpress.stackexchange.com/a/195002
		$subcategory = 'woocommerce-shop-page';
	}
	elseif ( is_archive() ) {
		$subcategory = 'blog';
	}

	$translated_key = $more_specific_layout_setting_identifiers[ $key ][ $subcategory ];

	if  ( $post ) {
		$layout_option_value = airpro_get_rwmb_meta( str_replace( '-', '_', $key ), $post->ID );
	}
	if ( ! $layout_option_value ) {
		$layout_option_value = airpro_get_option( $translated_key, false );
	}

	return $layout_option_value;
}

function airpro_page_title_is_enabled_for_current_page() {	
	$should_use = airpro_get_rwmb_meta( 'should_use_page_title', get_queried_object_id() );	// https://davidsutoyo.com/2016/07/15/get-page-id-outside-loop/
	$title_usage_was_overwritten_on_individual_page = $should_use !== '';
	if ( $title_usage_was_overwritten_on_individual_page ) {
		return airpro_check_bool( $should_use );
	}

	if ( is_single() ) {
		$should_use = airpro_get_option( 'archive-single-use-page-title', true );
	}
	elseif ( is_home() ) {
		$should_use = airpro_get_option( 'blog-archive-use-page-title', true );
	}
	else {
		$should_use = airpro_get_option( 'page-use-page-title', true );
	}

	return $should_use;
}

function airpro_breadcrumbs_are_enabled_for_current_page() {
	$should_use = airpro_get_rwmb_meta( 'page_title_breadcrumbs', get_queried_object_id() );
	$breadcrumbs_usage_was_overwritten_on_individual_page = $should_use !== '';
	if ( $breadcrumbs_usage_was_overwritten_on_individual_page ) {
		return airpro_check_bool( $should_use );
	}

	if ( is_single() ) {
		$should_use = airpro_get_option( 'archive-single-breadcrumbs-enable', true );
	}
	elseif ( is_home() ) {
		$should_use = airpro_get_option( 'blog-archive-breadcrumbs-enable', true );
	}
	else {
		$should_use = airpro_get_option( 'page-title-breadcrumbs-enable', true );
	}

	return $should_use;
}

function airpro_check_bool( $in ) {
	// found at https://github.com/wpbakery/vc-dev-example/blob/master/test_vc_map.php
	if ( strlen( $in ) > 0 && in_array( strtolower( $in ), array( "yes", "true", "1", "on", 1 ) )
	) {
		return true;
	}
	return false;
}

function airpro_get_layout_settings_arguments_for_template_parts() {
	$theme_options_isnt_fully_functioning_so_return_default_values = ! class_exists('Redux');
	if ( $theme_options_isnt_fully_functioning_so_return_default_values ) {
		return array(
			'sidebar_layout' => 'none',
			'use_header' => true,
			'use_footer' => true
		);
	}

	$sidebar_layout = airpro_get_layout_option( 'page-sidebar-layout' );	/* left, right, none */
	$use_header = airpro_get_layout_option( 'use-header' );
	$use_footer = airpro_get_layout_option( 'use-footer' );

	$argument_for_template_parts = array(
		'sidebar_layout' => $sidebar_layout,
		'use_header' => $use_header,
		'use_footer' => $use_footer
	);

	return $argument_for_template_parts;
}

function airpro_get_child_pages() {

	global $post;

	$args = array(
		'child_of' => $post->ID,
		'sort_column' => 'menu_order',
	);

	$pages = get_pages($args);
	return count($pages);

}

function airpro_get_top_ancestor_id() {

	global $post;

	if ($post->post_parent) {
		$ancestors = array_reverse(get_post_ancestors($post->ID));
		return $ancestors[0];

	}

	return $post->ID;

}

function airpro_get_blog_thumbnail_based_on_context() {
	$sidebar_position = airpro_get_layout_option( 'page-sidebar-layout' );
	$should_load_fullsize_image = 'none' === $sidebar_position;
	$size_to_load = $should_load_fullsize_image
		? 'full'
		: 'airpro-featured-image';

	return airpro_get_thumbnail( $size_to_load );
}

function airpro_get_page_title_background_css_if_set() {
	$css_array = airpro_get_rwmb_meta_value( 'page_title_background', get_queried_object_id() );	// https://davidsutoyo.com/2016/07/15/get-page-id-outside-loop/
	if ( empty( $css_array ) ) {
		return '';
	}

	$chosen_background_css_array = $css_array[ 0 ];
	if ( empty( $chosen_background_css_array ) ) {
		return '';
	}

	$significant_attributes = array( 'image', 'color' );

	$should_skip_setting_background = true;
	foreach ( $significant_attributes as $attr ){
		$significant_attribute_is_missing =
			! array_key_exists( $attr, $chosen_background_css_array ) || empty( $chosen_background_css_array[ $attr ] );
		$should_skip_setting_background = 
			$should_skip_setting_background && $significant_attribute_is_missing;
	}
	if ( $should_skip_setting_background ) {
		return '';
	}

	$css = '';
	foreach ( $chosen_background_css_array as $attr=>$value ) {
		$value_to_set = empty( $value )
			? 'initial'
			: $value;
		if ( 'image' == $attr ) {
			$value_to_set = $value_to_set == 'initial'
				? sprintf( 'url()' )
				: sprintf( 'url( %1$s )', $value_to_set );
		}
		$css .= sprintf( 'background-%1$s : %2$s; ', $attr, $value_to_set );
	}
	
	return $css;
}
